# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'CGNS/NAV/T/Q7ToolsWindow.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Q7ToolsWindow(object):
    def setupUi(self, Q7ToolsWindow):
        Q7ToolsWindow.setObjectName("Q7ToolsWindow")
        Q7ToolsWindow.setWindowModality(QtCore.Qt.NonModal)
        Q7ToolsWindow.resize(580, 364)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Q7ToolsWindow.sizePolicy().hasHeightForWidth())
        Q7ToolsWindow.setSizePolicy(sizePolicy)
        Q7ToolsWindow.setMinimumSize(QtCore.QSize(580, 364))
        Q7ToolsWindow.setMaximumSize(QtCore.QSize(580, 364))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/cgSpy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Q7ToolsWindow.setWindowIcon(icon)
        self.verticalLayout = QtWidgets.QVBoxLayout(Q7ToolsWindow)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.tabWidget = QtWidgets.QTabWidget(Q7ToolsWindow)
        self.tabWidget.setEnabled(True)
        self.tabWidget.setObjectName("tabWidget")
        self.Queries = QtWidgets.QWidget()
        self.Queries.setObjectName("Queries")
        self.label_15 = QtWidgets.QLabel(self.Queries)
        self.label_15.setGeometry(QtCore.QRect(50, 25, 37, 25))
        self.label_15.setObjectName("label_15")
        self.cGroup = QtWidgets.QComboBox(self.Queries)
        self.cGroup.setEnabled(True)
        self.cGroup.setGeometry(QtCore.QRect(95, 25, 74, 21))
        self.cGroup.setObjectName("cGroup")
        self.label_16 = QtWidgets.QLabel(self.Queries)
        self.label_16.setGeometry(QtCore.QRect(50, 55, 36, 25))
        self.label_16.setObjectName("label_16")
        self.cQuery = QtWidgets.QComboBox(self.Queries)
        self.cQuery.setGeometry(QtCore.QRect(95, 55, 378, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cQuery.sizePolicy().hasHeightForWidth())
        self.cQuery.setSizePolicy(sizePolicy)
        self.cQuery.setObjectName("cQuery")
        self.bOperateDoc = QtWidgets.QPushButton(self.Queries)
        self.bOperateDoc.setGeometry(QtCore.QRect(15, 55, 25, 25))
        self.bOperateDoc.setMinimumSize(QtCore.QSize(25, 25))
        self.bOperateDoc.setMaximumSize(QtCore.QSize(25, 25))
        self.bOperateDoc.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/operate-doc.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bOperateDoc.setIcon(icon1)
        self.bOperateDoc.setObjectName("bOperateDoc")
        self.spinBox = QtWidgets.QSpinBox(self.Queries)
        self.spinBox.setGeometry(QtCore.QRect(190, 235, 53, 22))
        self.spinBox.setObjectName("spinBox")
        self.checkBox = QtWidgets.QCheckBox(self.Queries)
        self.checkBox.setEnabled(False)
        self.checkBox.setGeometry(QtCore.QRect(20, 240, 171, 20))
        self.checkBox.setObjectName("checkBox")
        self.groupBox_2 = QtWidgets.QGroupBox(self.Queries)
        self.groupBox_2.setEnabled(True)
        self.groupBox_2.setGeometry(QtCore.QRect(15, 94, 521, 131))
        self.groupBox_2.setObjectName("groupBox_2")
        self.radioButton = QtWidgets.QRadioButton(self.groupBox_2)
        self.radioButton.setEnabled(False)
        self.radioButton.setGeometry(QtCore.QRect(15, 20, 261, 20))
        self.radioButton.setObjectName("radioButton")
        self.eUserVariable = QtWidgets.QLineEdit(self.groupBox_2)
        self.eUserVariable.setGeometry(QtCore.QRect(130, 70, 376, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.eUserVariable.sizePolicy().hasHeightForWidth())
        self.eUserVariable.setSizePolicy(sizePolicy)
        self.eUserVariable.setObjectName("eUserVariable")
        self.radioButton_2 = QtWidgets.QRadioButton(self.groupBox_2)
        self.radioButton_2.setEnabled(True)
        self.radioButton_2.setGeometry(QtCore.QRect(15, 70, 92, 20))
        self.radioButton_2.setObjectName("radioButton_2")
        self.radioButton_3 = QtWidgets.QRadioButton(self.groupBox_2)
        self.radioButton_3.setEnabled(False)
        self.radioButton_3.setGeometry(QtCore.QRect(15, 95, 131, 20))
        self.radioButton_3.setObjectName("radioButton_3")
        self.lineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEdit.setEnabled(False)
        self.lineEdit.setGeometry(QtCore.QRect(130, 95, 376, 21))
        self.lineEdit.setObjectName("lineEdit")
        self.radioButton_4 = QtWidgets.QRadioButton(self.groupBox_2)
        self.radioButton_4.setEnabled(False)
        self.radioButton_4.setGeometry(QtCore.QRect(15, 45, 426, 20))
        self.radioButton_4.setObjectName("radioButton_4")
        self.pushButton = QtWidgets.QPushButton(self.Queries)
        self.pushButton.setGeometry(QtCore.QRect(510, 55, 25, 25))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(25)
        sizePolicy.setVerticalStretch(25)
        sizePolicy.setHeightForWidth(self.pushButton.sizePolicy().hasHeightForWidth())
        self.pushButton.setSizePolicy(sizePolicy)
        self.pushButton.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButton.setMaximumSize(QtCore.QSize(25, 25))
        self.pushButton.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/images/icons/flag-none.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton.setIcon(icon2)
        self.pushButton.setObjectName("pushButton")
        self.bApplyBox = QtWidgets.QFrame(self.Queries)
        self.bApplyBox.setGeometry(QtCore.QRect(495, 235, 36, 36))
        self.bApplyBox.setFrameShape(QtWidgets.QFrame.Box)
        self.bApplyBox.setFrameShadow(QtWidgets.QFrame.Plain)
        self.bApplyBox.setLineWidth(2)
        self.bApplyBox.setObjectName("bApplyBox")
        self.bApply = QtWidgets.QPushButton(self.bApplyBox)
        self.bApply.setGeometry(QtCore.QRect(5, 5, 25, 25))
        self.bApply.setMinimumSize(QtCore.QSize(25, 25))
        self.bApply.setMaximumSize(QtCore.QSize(25, 25))
        self.bApply.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/images/icons/operate-execute.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bApply.setIcon(icon3)
        self.bApply.setObjectName("bApply")
        self.tabWidget.addTab(self.Queries, "")
        self.search = QtWidgets.QWidget()
        self.search.setObjectName("search")
        self.verticalLayoutWidget = QtWidgets.QWidget(self.search)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(5, 5, 541, 271))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.groupBox = QtWidgets.QGroupBox(self.verticalLayoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setTitle("")
        self.groupBox.setObjectName("groupBox")
        self.bSaveAsQuery = QtWidgets.QPushButton(self.groupBox)
        self.bSaveAsQuery.setGeometry(QtCore.QRect(350, 235, 24, 24))
        self.bSaveAsQuery.setMinimumSize(QtCore.QSize(24, 24))
        self.bSaveAsQuery.setMaximumSize(QtCore.QSize(24, 24))
        self.bSaveAsQuery.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/images/icons/operate-save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSaveAsQuery.setIcon(icon4)
        self.bSaveAsQuery.setObjectName("bSaveAsQuery")
        self.eSaveAsQuery = QtWidgets.QLineEdit(self.groupBox)
        self.eSaveAsQuery.setGeometry(QtCore.QRect(80, 235, 261, 21))
        self.eSaveAsQuery.setObjectName("eSaveAsQuery")
        self.sLevel = QtWidgets.QSlider(self.groupBox)
        self.sLevel.setGeometry(QtCore.QRect(420, 100, 16, 56))
        self.sLevel.setMaximum(2)
        self.sLevel.setSliderPosition(1)
        self.sLevel.setOrientation(QtCore.Qt.Vertical)
        self.sLevel.setInvertedAppearance(True)
        self.sLevel.setInvertedControls(True)
        self.sLevel.setTickPosition(QtWidgets.QSlider.TicksAbove)
        self.sLevel.setObjectName("sLevel")
        self.label_7 = QtWidgets.QLabel(self.groupBox)
        self.label_7.setGeometry(QtCore.QRect(360, 95, 53, 15))
        self.label_7.setObjectName("label_7")
        self.label_8 = QtWidgets.QLabel(self.groupBox)
        self.label_8.setGeometry(QtCore.QRect(360, 120, 53, 15))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_8.setFont(font)
        self.label_8.setObjectName("label_8")
        self.label_14 = QtWidgets.QLabel(self.groupBox)
        self.label_14.setGeometry(QtCore.QRect(360, 145, 53, 15))
        self.label_14.setObjectName("label_14")
        self.gCriteria = QtWidgets.QGroupBox(self.groupBox)
        self.gCriteria.setGeometry(QtCore.QRect(10, 10, 336, 196))
        self.gCriteria.setObjectName("gCriteria")
        self.label_9 = QtWidgets.QLabel(self.gCriteria)
        self.label_9.setGeometry(QtCore.QRect(15, 30, 76, 16))
        self.label_9.setObjectName("label_9")
        self.eName = QtWidgets.QLineEdit(self.gCriteria)
        self.eName.setGeometry(QtCore.QRect(75, 25, 181, 21))
        self.eName.setObjectName("eName")
        self.cDataCheck = QtWidgets.QGroupBox(self.gCriteria)
        self.cDataCheck.setEnabled(True)
        self.cDataCheck.setGeometry(QtCore.QRect(10, 85, 316, 106))
        self.cDataCheck.setCheckable(True)
        self.cDataCheck.setChecked(False)
        self.cDataCheck.setObjectName("cDataCheck")
        self.cDataType = QtWidgets.QComboBox(self.cDataCheck)
        self.cDataType.setGeometry(QtCore.QRect(65, 40, 41, 22))
        self.cDataType.setObjectName("cDataType")
        self.label_11 = QtWidgets.QLabel(self.cDataCheck)
        self.label_11.setGeometry(QtCore.QRect(10, 45, 76, 16))
        self.label_11.setObjectName("label_11")
        self.label_12 = QtWidgets.QLabel(self.cDataCheck)
        self.label_12.setGeometry(QtCore.QRect(10, 75, 76, 16))
        self.label_12.setObjectName("label_12")
        self.eValue = QtWidgets.QLineEdit(self.cDataCheck)
        self.eValue.setGeometry(QtCore.QRect(65, 15, 181, 21))
        self.eValue.setObjectName("eValue")
        self.label_13 = QtWidgets.QLabel(self.cDataCheck)
        self.label_13.setGeometry(QtCore.QRect(10, 20, 76, 16))
        self.label_13.setObjectName("label_13")
        self.eMaxSize = QtWidgets.QSpinBox(self.cDataCheck)
        self.eMaxSize.setGeometry(QtCore.QRect(65, 70, 81, 22))
        self.eMaxSize.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.eMaxSize.setProperty("value", 65)
        self.eMaxSize.setObjectName("eMaxSize")
        self.cRegexpValue = QtWidgets.QPushButton(self.cDataCheck)
        self.cRegexpValue.setGeometry(QtCore.QRect(250, 15, 24, 24))
        self.cRegexpValue.setMinimumSize(QtCore.QSize(24, 24))
        self.cRegexpValue.setMaximumSize(QtCore.QSize(24, 24))
        self.cRegexpValue.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/images/icons/regexp.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cRegexpValue.setIcon(icon5)
        self.cRegexpValue.setCheckable(True)
        self.cRegexpValue.setObjectName("cRegexpValue")
        self.cNotValue = QtWidgets.QPushButton(self.cDataCheck)
        self.cNotValue.setGeometry(QtCore.QRect(280, 15, 24, 24))
        self.cNotValue.setMinimumSize(QtCore.QSize(24, 24))
        self.cNotValue.setMaximumSize(QtCore.QSize(24, 24))
        self.cNotValue.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/images/icons/delete.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.cNotValue.setIcon(icon6)
        self.cNotValue.setCheckable(True)
        self.cNotValue.setObjectName("cNotValue")
        self.cNotDataType = QtWidgets.QPushButton(self.cDataCheck)
        self.cNotDataType.setGeometry(QtCore.QRect(280, 45, 24, 24))
        self.cNotDataType.setMinimumSize(QtCore.QSize(24, 24))
        self.cNotDataType.setMaximumSize(QtCore.QSize(24, 24))
        self.cNotDataType.setText("")
        self.cNotDataType.setIcon(icon6)
        self.cNotDataType.setCheckable(True)
        self.cNotDataType.setObjectName("cNotDataType")
        self.label_10 = QtWidgets.QLabel(self.gCriteria)
        self.label_10.setGeometry(QtCore.QRect(15, 60, 76, 16))
        self.label_10.setObjectName("label_10")
        self.cSIDStype = QtWidgets.QComboBox(self.gCriteria)
        self.cSIDStype.setGeometry(QtCore.QRect(75, 55, 181, 22))
        self.cSIDStype.setEditable(True)
        self.cSIDStype.setObjectName("cSIDStype")
        self.cRegexpName = QtWidgets.QPushButton(self.gCriteria)
        self.cRegexpName.setGeometry(QtCore.QRect(260, 25, 24, 24))
        self.cRegexpName.setMinimumSize(QtCore.QSize(24, 24))
        self.cRegexpName.setMaximumSize(QtCore.QSize(24, 24))
        self.cRegexpName.setText("")
        self.cRegexpName.setIcon(icon5)
        self.cRegexpName.setCheckable(True)
        self.cRegexpName.setObjectName("cRegexpName")
        self.cNotName = QtWidgets.QPushButton(self.gCriteria)
        self.cNotName.setGeometry(QtCore.QRect(290, 25, 24, 24))
        self.cNotName.setMinimumSize(QtCore.QSize(24, 24))
        self.cNotName.setMaximumSize(QtCore.QSize(24, 24))
        self.cNotName.setText("")
        self.cNotName.setIcon(icon6)
        self.cNotName.setCheckable(True)
        self.cNotName.setObjectName("cNotName")
        self.cRegexpSIDStype = QtWidgets.QPushButton(self.gCriteria)
        self.cRegexpSIDStype.setGeometry(QtCore.QRect(260, 55, 24, 24))
        self.cRegexpSIDStype.setMinimumSize(QtCore.QSize(24, 24))
        self.cRegexpSIDStype.setMaximumSize(QtCore.QSize(24, 24))
        self.cRegexpSIDStype.setText("")
        self.cRegexpSIDStype.setIcon(icon5)
        self.cRegexpSIDStype.setCheckable(True)
        self.cRegexpSIDStype.setObjectName("cRegexpSIDStype")
        self.cNotSIDStype = QtWidgets.QPushButton(self.gCriteria)
        self.cNotSIDStype.setGeometry(QtCore.QRect(290, 55, 24, 24))
        self.cNotSIDStype.setMinimumSize(QtCore.QSize(24, 24))
        self.cNotSIDStype.setMaximumSize(QtCore.QSize(24, 24))
        self.cNotSIDStype.setText("")
        self.cNotSIDStype.setIcon(icon6)
        self.cNotSIDStype.setCheckable(True)
        self.cNotSIDStype.setObjectName("cNotSIDStype")
        self.rAddToCurrent = QtWidgets.QRadioButton(self.groupBox)
        self.rAddToCurrent.setGeometry(QtCore.QRect(355, 15, 176, 20))
        self.rAddToCurrent.setChecked(True)
        self.rAddToCurrent.setObjectName("rAddToCurrent")
        self.rClearCurrent = QtWidgets.QRadioButton(self.groupBox)
        self.rClearCurrent.setGeometry(QtCore.QRect(355, 55, 171, 20))
        self.rClearCurrent.setObjectName("rClearCurrent")
        self.rWithinCurrent = QtWidgets.QRadioButton(self.groupBox)
        self.rWithinCurrent.setGeometry(QtCore.QRect(355, 35, 156, 20))
        self.rWithinCurrent.setObjectName("rWithinCurrent")
        self.bRunSearch = QtWidgets.QPushButton(self.groupBox)
        self.bRunSearch.setGeometry(QtCore.QRect(350, 175, 24, 24))
        self.bRunSearch.setMinimumSize(QtCore.QSize(24, 24))
        self.bRunSearch.setMaximumSize(QtCore.QSize(24, 24))
        self.bRunSearch.setText("")
        self.bRunSearch.setIcon(icon3)
        self.bRunSearch.setObjectName("bRunSearch")
        self.line = QtWidgets.QFrame(self.groupBox)
        self.line.setGeometry(QtCore.QRect(10, 215, 516, 16))
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.label_19 = QtWidgets.QLabel(self.groupBox)
        self.label_19.setGeometry(QtCore.QRect(40, 240, 53, 15))
        self.label_19.setObjectName("label_19")
        self.bFindQuery = QtWidgets.QPushButton(self.groupBox)
        self.bFindQuery.setGeometry(QtCore.QRect(10, 235, 24, 24))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(24)
        sizePolicy.setVerticalStretch(24)
        sizePolicy.setHeightForWidth(self.bFindQuery.sizePolicy().hasHeightForWidth())
        self.bFindQuery.setSizePolicy(sizePolicy)
        self.bFindQuery.setMinimumSize(QtCore.QSize(24, 24))
        self.bFindQuery.setMaximumSize(QtCore.QSize(24, 24))
        self.bFindQuery.setText("")
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/images/icons/zoompoint.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bFindQuery.setIcon(icon7)
        self.bFindQuery.setObjectName("bFindQuery")
        self.eWithLinks = QtWidgets.QCheckBox(self.groupBox)
        self.eWithLinks.setGeometry(QtCore.QRect(385, 180, 111, 20))
        self.eWithLinks.setChecked(True)
        self.eWithLinks.setObjectName("eWithLinks")
        self.verticalLayout_2.addWidget(self.groupBox)
        self.tabWidget.addTab(self.search, "")
        self.diff = QtWidgets.QWidget()
        self.diff.setObjectName("diff")
        self.gdiff = QtWidgets.QGroupBox(self.diff)
        self.gdiff.setGeometry(QtCore.QRect(5, 5, 541, 266))
        self.gdiff.setObjectName("gdiff")
        self.label = QtWidgets.QLabel(self.gdiff)
        self.label.setGeometry(QtCore.QRect(25, 25, 58, 16))
        self.label.setObjectName("label")
        self.cAncestor = QtWidgets.QComboBox(self.gdiff)
        self.cAncestor.setGeometry(QtCore.QRect(15, 45, 81, 22))
        self.cAncestor.setObjectName("cAncestor")
        self.cVersionA = QtWidgets.QComboBox(self.gdiff)
        self.cVersionA.setGeometry(QtCore.QRect(140, 45, 81, 22))
        self.cVersionA.setObjectName("cVersionA")
        self.label_2 = QtWidgets.QLabel(self.gdiff)
        self.label_2.setGeometry(QtCore.QRect(150, 25, 58, 16))
        self.label_2.setObjectName("label_2")
        self.cShowA = QtWidgets.QCheckBox(self.gdiff)
        self.cShowA.setEnabled(False)
        self.cShowA.setGeometry(QtCore.QRect(235, 45, 176, 21))
        self.cShowA.setCheckable(True)
        self.cShowA.setChecked(False)
        self.cShowA.setObjectName("cShowA")
        self.bDiff = QtWidgets.QPushButton(self.gdiff)
        self.bDiff.setGeometry(QtCore.QRect(395, 45, 25, 25))
        self.bDiff.setMinimumSize(QtCore.QSize(25, 25))
        self.bDiff.setMaximumSize(QtCore.QSize(25, 25))
        self.bDiff.setText("")
        self.bDiff.setIcon(icon3)
        self.bDiff.setObjectName("bDiff")
        self.tabWidget.addTab(self.diff, "")
        self.merge = QtWidgets.QWidget()
        self.merge.setObjectName("merge")
        self.gdiff_2 = QtWidgets.QGroupBox(self.merge)
        self.gdiff_2.setEnabled(False)
        self.gdiff_2.setGeometry(QtCore.QRect(5, 5, 541, 266))
        self.gdiff_2.setObjectName("gdiff_2")
        self.bMerge = QtWidgets.QPushButton(self.gdiff_2)
        self.bMerge.setGeometry(QtCore.QRect(415, 130, 25, 25))
        self.bMerge.setMinimumSize(QtCore.QSize(25, 25))
        self.bMerge.setMaximumSize(QtCore.QSize(25, 25))
        self.bMerge.setText("")
        self.bMerge.setIcon(icon3)
        self.bMerge.setObjectName("bMerge")
        self.groupBox_5 = QtWidgets.QGroupBox(self.gdiff_2)
        self.groupBox_5.setGeometry(QtCore.QRect(150, 20, 386, 81))
        self.groupBox_5.setObjectName("groupBox_5")
        self.cTreeA = QtWidgets.QComboBox(self.groupBox_5)
        self.cTreeA.setGeometry(QtCore.QRect(10, 20, 81, 22))
        self.cTreeA.setObjectName("cTreeA")
        self.rForceA = QtWidgets.QRadioButton(self.groupBox_5)
        self.rForceA.setGeometry(QtCore.QRect(160, 15, 201, 21))
        self.rForceA.setObjectName("rForceA")
        self.rAncestorA = QtWidgets.QRadioButton(self.groupBox_5)
        self.rAncestorA.setGeometry(QtCore.QRect(160, 35, 226, 21))
        self.rAncestorA.setObjectName("rAncestorA")
        self.ePrefixA = QtWidgets.QLineEdit(self.groupBox_5)
        self.ePrefixA.setGeometry(QtCore.QRect(10, 50, 76, 22))
        self.ePrefixA.setObjectName("ePrefixA")
        self.label_5 = QtWidgets.QLabel(self.groupBox_5)
        self.label_5.setGeometry(QtCore.QRect(90, 50, 58, 16))
        self.label_5.setObjectName("label_5")
        self.groupBox_6 = QtWidgets.QGroupBox(self.gdiff_2)
        self.groupBox_6.setGeometry(QtCore.QRect(150, 180, 386, 81))
        self.groupBox_6.setObjectName("groupBox_6")
        self.cTreeB = QtWidgets.QComboBox(self.groupBox_6)
        self.cTreeB.setGeometry(QtCore.QRect(10, 20, 81, 22))
        self.cTreeB.setObjectName("cTreeB")
        self.rForceB = QtWidgets.QRadioButton(self.groupBox_6)
        self.rForceB.setGeometry(QtCore.QRect(155, 15, 201, 21))
        self.rForceB.setObjectName("rForceB")
        self.rAncestorB = QtWidgets.QRadioButton(self.groupBox_6)
        self.rAncestorB.setGeometry(QtCore.QRect(155, 35, 226, 21))
        self.rAncestorB.setObjectName("rAncestorB")
        self.ePrefixB = QtWidgets.QLineEdit(self.groupBox_6)
        self.ePrefixB.setGeometry(QtCore.QRect(10, 50, 76, 22))
        self.ePrefixB.setObjectName("ePrefixB")
        self.label_6 = QtWidgets.QLabel(self.groupBox_6)
        self.label_6.setGeometry(QtCore.QRect(90, 55, 58, 16))
        self.label_6.setObjectName("label_6")
        self.groupBox_7 = QtWidgets.QGroupBox(self.gdiff_2)
        self.groupBox_7.setGeometry(QtCore.QRect(5, 100, 381, 76))
        self.groupBox_7.setObjectName("groupBox_7")
        self.cTreeAncestor = QtWidgets.QComboBox(self.groupBox_7)
        self.cTreeAncestor.setEnabled(False)
        self.cTreeAncestor.setGeometry(QtCore.QRect(10, 30, 81, 22))
        self.cTreeAncestor.setObjectName("cTreeAncestor")
        self.rForceNone = QtWidgets.QRadioButton(self.groupBox_7)
        self.rForceNone.setGeometry(QtCore.QRect(115, 10, 216, 21))
        self.rForceNone.setObjectName("rForceNone")
        self.rAncestor = QtWidgets.QRadioButton(self.groupBox_7)
        self.rAncestor.setGeometry(QtCore.QRect(115, 30, 211, 21))
        self.rAncestor.setObjectName("rAncestor")
        self.cAutoMerge = QtWidgets.QCheckBox(self.gdiff_2)
        self.cAutoMerge.setGeometry(QtCore.QRect(450, 130, 86, 21))
        self.cAutoMerge.setObjectName("cAutoMerge")
        self.tabWidget.addTab(self.merge, "")
        self.horizontalLayout_2.addWidget(self.tabWidget)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.bInfo = QtWidgets.QPushButton(Q7ToolsWindow)
        self.bInfo.setMinimumSize(QtCore.QSize(25, 25))
        self.bInfo.setMaximumSize(QtCore.QSize(25, 25))
        self.bInfo.setText("")
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/images/icons/help-view.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bInfo.setIcon(icon8)
        self.bInfo.setObjectName("bInfo")
        self.horizontalLayout.addWidget(self.bInfo)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.bClose = QtWidgets.QPushButton(Q7ToolsWindow)
        self.bClose.setObjectName("bClose")
        self.horizontalLayout.addWidget(self.bClose)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(Q7ToolsWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Q7ToolsWindow)

    def retranslateUi(self, Q7ToolsWindow):
        _translate = QtCore.QCoreApplication.translate
        Q7ToolsWindow.setWindowTitle(_translate("Q7ToolsWindow", "Form"))
        self.label_15.setText(_translate("Q7ToolsWindow", "Group:"))
        self.label_16.setText(_translate("Q7ToolsWindow", "Query:"))
        self.bOperateDoc.setToolTip(_translate("Q7ToolsWindow", "Show Query doc"))
        self.checkBox.setText(_translate("Q7ToolsWindow", "Show predefined query #"))
        self.groupBox_2.setTitle(_translate("Q7ToolsWindow", "Query arguments :"))
        self.radioButton.setText(_translate("Q7ToolsWindow", "Use last selected value as arg"))
        self.radioButton_2.setText(_translate("Q7ToolsWindow", "Plain value"))
        self.radioButton_3.setText(_translate("Q7ToolsWindow", "Regexp value"))
        self.radioButton_4.setText(_translate("Q7ToolsWindow", "Use ALL selected value as arg (loop on values and add selections)"))
        self.bApply.setToolTip(_translate("Q7ToolsWindow", "Run Query"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.Queries), _translate("Q7ToolsWindow", "Queries"))
        self.bSaveAsQuery.setToolTip(_translate("Q7ToolsWindow", "Save as a query"))
        self.label_7.setText(_translate("Q7ToolsWindow", "Ancestor"))
        self.label_8.setText(_translate("Q7ToolsWindow", "Current"))
        self.label_14.setText(_translate("Q7ToolsWindow", "Children"))
        self.gCriteria.setTitle(_translate("Q7ToolsWindow", "###"))
        self.label_9.setText(_translate("Q7ToolsWindow", "name:"))
        self.cDataCheck.setTitle(_translate("Q7ToolsWindow", "Data"))
        self.label_11.setText(_translate("Q7ToolsWindow", "type:"))
        self.label_12.setText(_translate("Q7ToolsWindow", "max size:"))
        self.label_13.setText(_translate("Q7ToolsWindow", "value:"))
        self.cRegexpValue.setToolTip(_translate("Q7ToolsWindow", "String is a regular expression"))
        self.cNotValue.setToolTip(_translate("Q7ToolsWindow", "Use all strings but this one"))
        self.cNotDataType.setToolTip(_translate("Q7ToolsWindow", "Use all strings but this one"))
        self.label_10.setText(_translate("Q7ToolsWindow", "SIDS type:"))
        self.cRegexpName.setToolTip(_translate("Q7ToolsWindow", "String is a regular expression"))
        self.cNotName.setToolTip(_translate("Q7ToolsWindow", "Use all strings but this one"))
        self.cRegexpSIDStype.setToolTip(_translate("Q7ToolsWindow", "String is a regular expression"))
        self.cNotSIDStype.setToolTip(_translate("Q7ToolsWindow", "Use all strings but this one"))
        self.rAddToCurrent.setText(_translate("Q7ToolsWindow", "Add to current selection"))
        self.rClearCurrent.setText(_translate("Q7ToolsWindow", "Clear current selection first"))
        self.rWithinCurrent.setText(_translate("Q7ToolsWindow", "Within current selection"))
        self.bRunSearch.setToolTip(_translate("Q7ToolsWindow", "Run current selection criteria"))
        self.label_19.setText(_translate("Q7ToolsWindow", "name:"))
        self.bFindQuery.setToolTip(_translate("Q7ToolsWindow", "Load search query with this name"))
        self.eWithLinks.setText(_translate("Q7ToolsWindow", "Include links"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.search), _translate("Q7ToolsWindow", "Search"))
        self.gdiff.setTitle(_translate("Q7ToolsWindow", "All tree identifications use view number"))
        self.label.setText(_translate("Q7ToolsWindow", "Version A"))
        self.cAncestor.setToolTip(_translate("Q7ToolsWindow", "Select first tree to diff"))
        self.label_2.setText(_translate("Q7ToolsWindow", "Version B"))
        self.cShowA.setText(_translate("Q7ToolsWindow", "Show result on B view"))
        self.bDiff.setToolTip(_translate("Q7ToolsWindow", "Process the diff"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.diff), _translate("Q7ToolsWindow", "Diff"))
        self.gdiff_2.setTitle(_translate("Q7ToolsWindow", "All tree identifications use view number"))
        self.groupBox_5.setTitle(_translate("Q7ToolsWindow", "Version A"))
        self.rForceA.setText(_translate("Q7ToolsWindow", "Force A values when different"))
        self.rAncestorA.setText(_translate("Q7ToolsWindow", "A replaces the common ancestor"))
        self.label_5.setText(_translate("Q7ToolsWindow", "Prefix"))
        self.groupBox_6.setTitle(_translate("Q7ToolsWindow", "Version B"))
        self.rForceB.setText(_translate("Q7ToolsWindow", "Force B values when different"))
        self.rAncestorB.setText(_translate("Q7ToolsWindow", "B replaces the common ancestor"))
        self.label_6.setText(_translate("Q7ToolsWindow", "Prefix"))
        self.groupBox_7.setTitle(_translate("Q7ToolsWindow", "Ancestor"))
        self.rForceNone.setText(_translate("Q7ToolsWindow", "Keep both values when different"))
        self.rAncestor.setText(_translate("Q7ToolsWindow", "Use common ancestor"))
        self.cAutoMerge.setText(_translate("Q7ToolsWindow", "Auto"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.merge), _translate("Q7ToolsWindow", "Merge"))
        self.bClose.setText(_translate("Q7ToolsWindow", "Close"))
from . import Res_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'CGNS/NAV/T/Q7HelpWindow.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Q7HelpWindow(object):
    def setupUi(self, Q7HelpWindow):
        Q7HelpWindow.setObjectName("Q7HelpWindow")
        Q7HelpWindow.resize(715, 350)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Q7HelpWindow.sizePolicy().hasHeightForWidth())
        Q7HelpWindow.setSizePolicy(sizePolicy)
        Q7HelpWindow.setMinimumSize(QtCore.QSize(715, 350))
        Q7HelpWindow.setMaximumSize(QtCore.QSize(1200, 350))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/cgSpy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Q7HelpWindow.setWindowIcon(icon)
        self.gridLayout = QtWidgets.QGridLayout(Q7HelpWindow)
        self.gridLayout.setObjectName("gridLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.eHelp = QtWidgets.QTextEdit(Q7HelpWindow)
        self.eHelp.setObjectName("eHelp")
        self.verticalLayout.addWidget(self.eHelp)
        self.gridLayout.addLayout(self.verticalLayout, 3, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.bBackControl = QtWidgets.QPushButton(Q7HelpWindow)
        self.bBackControl.setEnabled(False)
        self.bBackControl.setMinimumSize(QtCore.QSize(25, 25))
        self.bBackControl.setMaximumSize(QtCore.QSize(25, 25))
        self.bBackControl.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/top.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bBackControl.setIcon(icon1)
        self.bBackControl.setObjectName("bBackControl")
        self.horizontalLayout_2.addWidget(self.bBackControl)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.gridLayout.addLayout(self.horizontalLayout_2, 4, 0, 1, 1)

        self.retranslateUi(Q7HelpWindow)
        QtCore.QMetaObject.connectSlotsByName(Q7HelpWindow)

    def retranslateUi(self, Q7HelpWindow):
        _translate = QtCore.QCoreApplication.translate
        Q7HelpWindow.setWindowTitle(_translate("Q7HelpWindow", "Form"))
from . import Res_rc



#  -------------------------------------------------------------------------
#  pyCGNS.NAV - Python package for CFD General Notation System - NAVigater
#  See license.txt file in the root directory of this Python module source  
#  -------------------------------------------------------------------------
#

import numpy
import CGNS.PAT.cgnsutils as CGU

from CGNS.NAV.moption import Q7OptionContext as OCTXT
import CGNS.NAV.mtree as NMT
from CGNS.NAV.mtree import (Q7TreeItem, Q7TreeModel, Q7TreeView)

from qtpy.QtCore import Qt
from qtpy.QtGui import QColor

(DIFF_NX, DIFF_NA, DIFF_ND, DIFF_CQ, DIFF_CT, DIFF_CS, DIFF_CV) = range(7)


# -----------------------------------------------------------------
class Q7DiffTreeModel(Q7TreeModel):
    def __init__(self, fgprintindex, parent=None):
        Q7TreeModel.__init__(self, fgprintindex, parent)
        self._diag = None
        self.orange = QColor(255, 165, 0, 255)
        self.orangeLight = QColor(255, 165, 0, 120)
        self.red = QColor(255, 0, 0, 255)
        self.redLight = QColor(255, 0, 0, 90)
        self.green = QColor(0, 128, 0, 255)
        self.greenLight = QColor(0, 128, 0, 90)
        self.gray = QColor(192, 192, 192, 255)
        self.grayLight = QColor(192, 192, 192, 192)

    def setDiag(self, diag):
        self._diag = diag

    def getDiag(self):
        return self._diag

    def data(self, index, role):
        idx = index
        col = idx.column()
        #nnm = index.internalPointer().sidsName()
        pth = CGU.getPathNoRoot(index.internalPointer().sidsPath())
        if ((role not in [Qt.BackgroundRole]) or
                (self._diag is None) or
                (pth not in self._diag)):
            return Q7TreeModel.data(self, index, role)
        if col == NMT.COLUMN_NAME:
            if self._diag[pth] == DIFF_NX:
                return self.grayLight
            if self._diag[pth] == DIFF_NA:
                return self.greenLight
            if self._diag[pth] == DIFF_ND:
                return self.redLight
            return self.grayLight
        elif col == NMT.COLUMN_DATATYPE:
            if self._diag[pth] == DIFF_CQ:
                return self.orangeLight
        elif col == NMT.COLUMN_SHAPE:
            if self._diag[pth] == DIFF_CS:
                return self.orangeLight
        elif col == NMT.COLUMN_SIDS:
            if self._diag[pth] == DIFF_CT:
                return self.orangeLight
        return Q7TreeModel.data(self, index, role)


# -----------------------------------------------------------------
class Q7DiffTreeView(Q7TreeView):
    def __init__(self, parent):
        Q7TreeView.__init__(self, parent)


# -----------------------------------------------------------------
class Q7DiffItem(Q7TreeItem):
    def __init__(self, fgprint, data, model, tag="", parent=None):
        super(Q7DiffItem, self).__init__(self, fgprint, data, model, tag, parent)

    def columnCount(self):
        return NMT.COLUMN_LAST + 1

    def data(self, column):
        if self._itemnode is None:
            return self._title[column]
        if column == NMT.COLUMN_NAME:
            return self.sidsName()
        if column == NMT.COLUMN_SIDS:
            return self.sidsType()
        if column == NMT.COLUMN_FLAG_LINK:
            return self.sidsLinkStatus()
        if column == NMT.COLUMN_SHAPE:
            if self.sidsValue() is None:
                return None
            if not isinstance(self.sidsValue(), numpy.ndarray):
                return None
            return str(self.sidsValue().shape)
        if column == NMT.COLUMN_FLAG_SELECT:
            return self._states['mark']
        if column == NMT.COLUMN_DATATYPE:
            return self.sidsDataType()
        if column == NMT.COLUMN_FLAG_CHECK:
            return self._states['check']
        if column == NMT.COLUMN_FLAG_USER:
            return self._states['user']
        if column == NMT.COLUMN_VALUE:
            if self._lazy:
                return NMT.LAZYVALUE
            if self.sidsValue() is None:
                return None
            if isinstance(self.sidsValue(), numpy.ndarray):
                vsize = 1
                for x in self.sidsValue().shape:
                    vsize *= x
                if ((vsize > OCTXT.MaxDisplayDataSize) and
                        (OCTXT.MaxDisplayDataSize > 0)):
                    return NMT.HIDEVALUE
                if self.sidsValue().dtype.char in ['S', 'c']:
                    if len(self.sidsValue().shape) == 1:
                        return self.sidsValue().tostring().decode('ascii')
                    if len(self.sidsValue().shape) > 2:
                        return NMT.HIDEVALUE
                    return NMT.HIDEVALUE
                if (self.sidsValue().shape == (1,)) and OCTXT.Show1DAsPlain:
                    return str(self.sidsValue()[0])
            return str(self.sidsValue().tolist())[:100]
        return None

# -----------------------------------------------------------------




# ----------------------------------------------------------------------
#
# cython: boundscheck=False
# cython: wraparound=False
# cython: cdivision=True
import CGNS.PAT.cgnskeywords as CGK
import  numpy as  NPY
cimport numpy as  NPY
import random

NPY.import_array()

cimport hashutils as HUT

# ----------------------------------------------------------------------
cdef int _trisFromTri(NPY.ndarray[NPY.int32_t, ndim=1] itris,
                      int itriscount,
                      NPY.ndarray[NPY.int32_t, ndim=1] otris,
                      int npe,int minr, int bnd,
                      HUT.F_entry_ptr h,int hsz,int sn):
  cdef int p=0,rix=0,f=0,dix,maxc
  cdef int *d
  cdef int *r
  maxc=itriscount
  if (bnd): maxc=bnd
  r  =<int*>otris.data
  d  =<int*>itris.data
  while (p<maxc):
    dix=p*npe-1
    if (not HUT.fetchHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+3],0,sn)):
      r[rix+0]=d[dix+1]
      r[rix+1]=d[dix+2]
      r[rix+2]=d[dix+3]
      rix=rix+3
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+3],0,minr+f,sn)
    p+=1
  return f

# ----------------------------------------------------------------------
cdef int _quadsFromQuad(NPY.ndarray[NPY.int32_t, ndim=1] iquads,
                        int iquadscount,
                        NPY.ndarray[NPY.int32_t, ndim=1] oquads,
                        int npe,int minr, int bnd,
                        HUT.F_entry_ptr h,int hsz,int sn):
  cdef int p=0,rix=0,f=0,dix,maxc
  cdef int *d
  cdef int *r
  maxc=iquadscount
  if (bnd): maxc=bnd
  r  =<int*>oquads.data
  d  =<int*>iquads.data
  while (p<maxc):
    dix=p*npe-1
    if (not HUT.fetchHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+3],d[dix+4],sn)):
      r[rix+0]=d[dix+1]
      r[rix+1]=d[dix+2]
      r[rix+2]=d[dix+3]
      r[rix+3]=d[dix+4]
      rix=rix+4
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+3],d[dix+4],minr+f,sn)
    p+=1
  return f

# ----------------------------------------------------------------------
cdef int _trisFromTetra(NPY.ndarray[NPY.int32_t, ndim=1] tetras,
                        int tetrascount,
                        NPY.ndarray[NPY.int32_t, ndim=1] tris,
                        int npe,int minr, int bnd,
                        HUT.F_entry_ptr h,int hsz,int sn):
  cdef int p=0,rix=0,f=0,dix,maxc
  cdef int *d
  cdef int *r
  maxc=tetrascount
  if (bnd): maxc=bnd
  r  =<int*>tris.data
  d  =<int*>tetras.data
  while (p<maxc):
    dix=p*npe-1
    if (not HUT.fetchHashEntry(h,hsz,d[dix+1],d[dix+3],d[dix+2],0,sn)):
      r[rix+0]=d[dix+1]
      r[rix+1]=d[dix+3]
      r[rix+2]=d[dix+2]
      rix=rix+3
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+1],d[dix+3],d[dix+2],0,minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+4],0,sn)):
      r[rix+0]=d[dix+1]
      r[rix+1]=d[dix+2]
      r[rix+2]=d[dix+4]
      rix=rix+3
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+4],0,minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+2],d[dix+3],d[dix+4],0,sn)):
      r[rix+0]=d[dix+2]
      r[rix+1]=d[dix+3]
      r[rix+2]=d[dix+4]
      rix=rix+3
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+2],d[dix+3],d[dix+4],0,minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+3],d[dix+1],d[dix+4],0,sn)):
      r[rix+0]=d[dix+3]
      r[rix+1]=d[dix+1]
      r[rix+2]=d[dix+4]
      rix=rix+3
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+3],d[dix+1],d[dix+4],0,minr+f,sn)
    p+=1
  return f

# ----------------------------------------------------------------------
cdef int _trisFromPyra(NPY.ndarray[NPY.int32_t, ndim=1] pyras,
                       int pyrascount,
                       NPY.ndarray[NPY.int32_t, ndim=1] tris,
                       int npe,int minr, int bnd,
                       HUT.F_entry_ptr h,int hsz,int sn):
  cdef int p=0,rix=0,m=0,f=0,dix,maxc
  cdef int *d
  cdef int *r
  cdef int *pr
  cdef int *ps
  maxc=pyrascount
  if (bnd): maxc=bnd
  r  =<int*>tris.data
  d  =<int*>pyras.data
  while (p<maxc):
    dix=p*npe-1
    if (not HUT.fetchHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+5],0,sn)):
      r[rix+0]=d[dix+1]
      r[rix+1]=d[dix+2]
      r[rix+2]=d[dix+5]
      rix=rix+3
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+5],0,minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+2],d[dix+3],d[dix+5],0,sn)):
      r[rix+0]=d[dix+2]
      r[rix+1]=d[dix+3]
      r[rix+2]=d[dix+5]
      rix=rix+3
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+2],d[dix+3],d[dix+5],0,minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+3],d[dix+4],d[dix+5],0,sn)):
      r[rix+0]=d[dix+3]
      r[rix+1]=d[dix+4]
      r[rix+2]=d[dix+5]
      rix=rix+3
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+3],d[dix+4],d[dix+5],0,minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+4],d[dix+1],d[dix+5],0,sn)):
      r[rix+0]=d[dix+4]
      r[rix+1]=d[dix+1]
      r[rix+2]=d[dix+5]
      rix=rix+3
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+4],d[dix+1],d[dix+5],0,minr+f,sn)
    p+=1
  return f

# ----------------------------------------------------------------------
cdef int _quadsFromPyra(NPY.ndarray[NPY.int32_t, ndim=1] pyras,
                        int pyrascount,
                        NPY.ndarray[NPY.int32_t, ndim=1] quads,
                        int npe,int minr, int bnd,
                        HUT.F_entry_ptr h,int hsz,int sn):
  cdef int p=0,rix=0,f=0,dix,maxc
  cdef int *d
  cdef int *r
  maxc=pyrascount
  if (bnd): maxc=bnd
  r  =<int*>quads.data
  d  =<int*>pyras.data
  while (p<maxc):
    dix=p*npe-1
    if (not HUT.fetchHashEntry(h,hsz,d[dix+1],d[dix+4],d[dix+3],d[dix+2],sn)):
      r[rix+0]=d[dix+1]
      r[rix+1]=d[dix+4]
      r[rix+2]=d[dix+3]
      r[rix+3]=d[dix+2]
      rix=rix+4
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+1],d[dix+4],d[dix+3],d[dix+2],minr+f,sn)
    p+=1
  return f

# ----------------------------------------------------------------------
cdef int _trisFromPenta(NPY.ndarray[NPY.int32_t, ndim=1] pentas,
                        int pentascount,
                        NPY.ndarray[NPY.int32_t, ndim=1] tris,
                        int npe,int minr, int bnd,
                        HUT.F_entry_ptr h,int hsz,int sn):
  cdef int p=0,rix=0,m=0,f=0,dix,maxc
  cdef int *d
  cdef int *r
  cdef int *pr
  cdef int *ps
  maxc=pentascount
  if (bnd): maxc=bnd
  r  =<int*>tris.data
  d  =<int*>pentas.data
  while (p<maxc):
    dix=p*npe-1
    if (not HUT.fetchHashEntry(h,hsz,d[dix+1],d[dix+3],d[dix+2],0,sn)):
      r[rix+0]=d[dix+1]
      r[rix+1]=d[dix+3]
      r[rix+2]=d[dix+2]
      rix=rix+3
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+1],d[dix+3],d[dix+2],0,minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+4],d[dix+5],d[dix+6],0,sn)):
      r[rix+0]=d[dix+4]
      r[rix+1]=d[dix+5]
      r[rix+2]=d[dix+6]
      rix=rix+3
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+4],d[dix+5],d[dix+6],0,minr+f,sn)
    p+=1
  return f

# ----------------------------------------------------------------------
cdef int _quadsFromPenta(NPY.ndarray[NPY.int32_t, ndim=1] pentas,
                         int pentascount,
                         NPY.ndarray[NPY.int32_t, ndim=1] quads,
                         int npe,int minr, int bnd,
                         HUT.F_entry_ptr h,int hsz,int sn):
  cdef int p=0,rix=0,f=0,dix,maxc
  cdef int *d
  cdef int *r
  maxc=pentascount
  if (bnd): maxc=bnd
  r  =<int*>quads.data
  d  =<int*>pentas.data
  while (p<maxc):
    dix=p*npe-1
    if (not HUT.fetchHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+5],d[dix+4],sn)):
      r[rix+0]=d[dix+1]
      r[rix+1]=d[dix+2]
      r[rix+2]=d[dix+5]
      r[rix+3]=d[dix+4]
      rix=rix+4
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+5],d[dix+4],minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+2],d[dix+3],d[dix+6],d[dix+5],sn)):
      r[rix+0]=d[dix+2]
      r[rix+1]=d[dix+3]
      r[rix+2]=d[dix+6]
      r[rix+3]=d[dix+5]
      rix=rix+4
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+2],d[dix+3],d[dix+6],d[dix+5],minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+3],d[dix+1],d[dix+4],d[dix+6],sn)):
      r[rix+0]=d[dix+3]
      r[rix+1]=d[dix+1]
      r[rix+2]=d[dix+4]
      r[rix+3]=d[dix+6]
      rix=rix+4
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+3],d[dix+1],d[dix+4],d[dix+6],minr+f,sn)
    p+=1
  return f

# ----------------------------------------------------------------------
cdef int _quadsFromHexa(NPY.ndarray[NPY.int32_t, ndim=1] hexas,
                        int hexascount,
                        NPY.ndarray[NPY.int32_t, ndim=1] quads,
                        int npe,int minr, int bnd,
                        HUT.F_entry_ptr h,int hsz,int sn):
  cdef int p=0,rix=0,m=0,f=0,dix,maxc
  cdef int *d
  cdef int *r
  maxc=hexascount
  if (bnd): maxc=bnd
  r  =<int*>quads.data
  d  =<int*>hexas.data
  while (p<maxc):
    dix=p*npe-1
    if (not HUT.fetchHashEntry(h,hsz,d[dix+1],d[dix+4],d[dix+3],d[dix+2],sn)):
      r[rix+0]=d[dix+1]
      r[rix+1]=d[dix+4]
      r[rix+2]=d[dix+3]
      r[rix+3]=d[dix+2]
      rix=rix+4
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+1],d[dix+4],d[dix+3],d[dix+2],minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+6],d[dix+5],sn)):
      r[rix+0]=d[dix+1]
      r[rix+1]=d[dix+2]
      r[rix+2]=d[dix+6]
      r[rix+3]=d[dix+5]
      rix=rix+4
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+1],d[dix+2],d[dix+6],d[dix+5],minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+2],d[dix+3],d[dix+7],d[dix+6],sn)):
      r[rix+0]=d[dix+2]
      r[rix+1]=d[dix+3]
      r[rix+2]=d[dix+7]
      r[rix+3]=d[dix+6]
      rix=rix+4
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+2],d[dix+3],d[dix+7],d[dix+6],minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+3],d[dix+4],d[dix+8],d[dix+7],sn)):
      r[rix+0]=d[dix+3]
      r[rix+1]=d[dix+4]
      r[rix+2]=d[dix+8]
      r[rix+3]=d[dix+7]
      rix=rix+4
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+3],d[dix+4],d[dix+8],d[dix+7],minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+1],d[dix+5],d[dix+8],d[dix+4],sn)):
      r[rix+0]=d[dix+1]
      r[rix+1]=d[dix+5]
      r[rix+2]=d[dix+8]
      r[rix+3]=d[dix+4]
      rix=rix+4
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+1],d[dix+5],d[dix+8],d[dix+4],minr+f,sn)
    if (not HUT.fetchHashEntry(h,hsz,d[dix+5],d[dix+6],d[dix+7],d[dix+8],sn)):
      r[rix+0]=d[dix+5]
      r[rix+1]=d[dix+6]
      r[rix+2]=d[dix+7]
      r[rix+3]=d[dix+8]
      rix=rix+4
      f+=1
      HUT.addHashEntry(h,hsz,d[dix+5],d[dix+6],d[dix+7],d[dix+8],minr+f,sn)
    p+=1
  return f

# ----------------------------------------------------------------------
cdef int _exteriorFaces(NPY.ndarray[NPY.int32_t, ndim=1] elts,
                        int eltscount,
                        NPY.ndarray[NPY.int32_t, ndim=1] xfaces,
                        int npe,
                        HUT.F_entry_ptr h,int hsz,int sn):
  cdef int p=0,rix=0,f=0,dix,dp=0
  cdef int *d
  cdef int *r
  r  =<int*>xfaces.data
  d  =<int*>elts.data
  while (p<eltscount):
    dix=p*npe
    if (npe==4): dp=d[dix+3]
    if (HUT.exteriorHashEntry(h,hsz,d[dix+0],d[dix+1],d[dix+2],dp,sn)==1):
      r[rix+0]=d[dix+0]
      r[rix+1]=d[dix+1]
      r[rix+2]=d[dix+2]
      if (npe==4):
          r[rix+3]=dp
          rix=rix+4
      else:
          rix=rix+3
      f+=1
    p+=1
  return f

# ----------------------------------------------------------------------
cdef class SectionParse(object):
  cdef HUT.F_entry_ptr facesH
  cdef int sizeH
  QUAD_SURFACE=[CGK.QUAD_4,CGK.QUAD_8,CGK.QUAD_9,
                CGK.PENTA_6,CGK.PENTA_15,CGK.PENTA_18,
                CGK.HEXA_8,CGK.HEXA_20,CGK.HEXA_27,
                CGK.PYRA_5,CGK.PYRA_13,CGK.PYRA_14]

  TRI_SURFACE =[CGK.TRI_3,CGK.TRI_6,
                CGK.PENTA_6,CGK.PENTA_15,CGK.PENTA_18,
                CGK.TETRA_4,CGK.TETRA_10,
                CGK.PYRA_5,CGK.PYRA_13,CGK.PYRA_14]

  QUAD_TYPES=[CGK.QUAD_4,CGK.QUAD_8,CGK.QUAD_9]
  PENTA_TYPES=[CGK.PENTA_6,CGK.PENTA_15,CGK.PENTA_18]
  HEXA_TYPES=[CGK.HEXA_8,CGK.HEXA_20,CGK.HEXA_27]
  PYRA_TYPES=[CGK.PYRA_5,CGK.PYRA_13,CGK.PYRA_14]
  TRI_TYPES=[CGK.TRI_3,CGK.TRI_6]
  TETRA_TYPES=[CGK.TETRA_4,CGK.TETRA_10]
  
  SURFACE_TYPES=QUAD_TYPES+TRI_TYPES

  def __cinit__(self):
    self.sizeH=44497
    self.sizeH=1686049
    self.facesH=HUT.newHashTable(self.sizeH)

  def __dealloc__(self):
    HUT.freeHashTable(self.facesH,self.sizeH)

  def extQuadFacesPoints(self,ea,et,sn,mr,b):
    if (et in self.QUAD_TYPES):  qnpe=1
    if (et in self.PENTA_TYPES): qnpe=3
    if (et in self.HEXA_TYPES):  qnpe=6
    if (et in self.PYRA_TYPES):  qnpe=1
    enpe=CGK.ElementTypeNPE[CGK.ElementType_l[et]]
    fnpe=4
    f=0
    ez=len(ea.flat)
    ec=ez//enpe
    re=NPY.zeros((ec*qnpe*fnpe),dtype=NPY.int32)
    h=self.facesH
    hsz=self.sizeH
    if (et in self.QUAD_TYPES):
      re=ea
      f=ec
    if (et in self.PENTA_TYPES):f=_quadsFromPenta(ea,ec,re,enpe,mr,b,h,hsz,sn)
    if (et in self.HEXA_TYPES): f=_quadsFromHexa(ea,ec,re,enpe,mr,b,h,hsz,sn)
    if (et in self.PYRA_TYPES): f=_quadsFromPyra(ea,ec,re,enpe,mr,b,h,hsz,sn)
    rx=NPY.zeros((f*fnpe),dtype=NPY.int32)
    re=re[:f*fnpe].copy()
    if (et in self.SURFACE_TYPES):
      rx=re
      fx=f
    else:
      fx=_exteriorFaces(re[:f*fnpe].copy(),f,rx,fnpe,h,hsz,sn)
    return (CGK.QUAD_4,rx[:fx*fnpe],mr,f+mr,fx+mr)

  def extTriFacesPoints(self,ea,et,sn,mr,b):
    if (et in self.TRI_TYPES):   qnpe=1
    if (et in self.PENTA_TYPES): qnpe=2
    if (et in self.TETRA_TYPES): qnpe=4
    if (et in self.PYRA_TYPES):  qnpe=4
    enpe=CGK.ElementTypeNPE[CGK.ElementType_l[et]]
    fnpe=3
    f=0
    ez=len(ea.flat)
    ec=ez//enpe
    re=NPY.zeros((ec*qnpe*fnpe),dtype=NPY.int32)
    h=self.facesH
    hsz=self.sizeH
    if (et in self.TRI_TYPES):
      re=ea
      f=ec
    if (et in self.PENTA_TYPES):f=_trisFromPenta(ea,ec,re,enpe,mr,b,h,hsz,sn)
    if (et in self.TETRA_TYPES):f=_trisFromTetra(ea,ec,re,enpe,mr,b,h,hsz,sn)
    if (et in self.PYRA_TYPES): f=_trisFromPyra(ea,ec,re,enpe,mr,b,h,hsz,sn)
    rx=NPY.zeros((f*fnpe),dtype=NPY.int32)
    if (et in self.SURFACE_TYPES):
      rx=re
      fx=f
    else:
      fx=_exteriorFaces(re[:f*fnpe].copy(),f,rx,fnpe,h,hsz,sn)
    return (CGK.TRI_3,rx[:fx*fnpe].copy(),mr,f+mr,fx+mr)
    
# ----------------------------------------------------------------------
# --- last line



#  -------------------------------------------------------------------------
#  pyCGNS - Python package for CFD General Notation System -
#  See license.txt file in the root directory of this Python module source  
#  -------------------------------------------------------------------------
# 
# Default values, would be overwritten during install
#
import sys

# --------------------------------------------------------------------
def pathfromexec(execname):
    import os
    for pth in os.environ['PATH']:
        apth = os.path.normpath(os.path.expanduser(pth))
        if os.path.exists(apth + '/' + execname): return pth
    return ''


mylocal = sys.prefix

# --------------------------------------------------------------------
INCLUDE_DIRS = ["%s/include" % mylocal]
LIBRARY_DIRS = ["%s/lib" % mylocal]

# Use integers instead of booleans, values are used in C files
HAS_H5PY = 0
HAS_HDF5 = 1

try:
    import vtk
    from CGNS.NAV.wvtk import Q7VTK
    HAS_VTK = 1
except ImportError:
    HAS_VTK = 0

HAS_MSW = 0
USE_COMPACT_STORAGE = 1

hdf5path = pathfromexec("h5dump")
HDF5_VERSION = "1.8"
HDF5_PATH_INCLUDES = [hdf5path + "../include"]
HDF5_PATH_LIBRARIES = [hdf5path + "../lib"]
HDF5_LINK_LIBRARIES = ["hdf5"]
HDF5_EXTRA_ARGS = []

NUMPY_VERSION = ""
NUMPY_VERSION_API = ""
NUMPY_PATH_INCLUDES = []
NUMPY_PATH_LIBRARIES = []
NUMPY_LINK_LIBRARIES = []
NUMPY_EXTRA_ARGS = []

PYQT_VERSION = ""
QT_VERSION = ""
CYTHON_VERSION = ""
VTK_VERSION = ""

# cannot manage include orders here...
INCLUDE_DIRS = INCLUDE_DIRS + HDF5_PATH_INCLUDES \
                + NUMPY_PATH_INCLUDES
LIBRARY_DIRS += LIBRARY_DIRS + HDF5_PATH_LIBRARIES \
                + NUMPY_PATH_LIBRARIES
#
# -------------------------------------------------------------------------
# You should not change values beyond this point
#
PFX = '### pyCGNS:'
#
file_pattern = """#  -------------------------------------------------------------------------
#  pyCGNS - Python package for CFD General Notation System
#  See license.txt file in the root directory of this Python module source  
#  -------------------------------------------------------------------------
# This file has been generated on [%(DATE)s]
# Using platform [%(PLATFORM)s]

DATE="%(DATE)s"
PLATFORM="%(PLATFORM)s"
PFX="%(PFX)s"

HAS_HDF5=%(HAS_HDF5)s
HAS_H5PY=%(HAS_H5PY)s
HAS_VTK=%(HAS_VTK)s
HAS_MSW=%(HAS_MSW)s
USE_COMPACT_STORAGE=%(USE_COMPACT_STORAGE)s

INCLUDE_DIRS=%(INCLUDE_DIRS)s
LIBRARY_DIRS=%(LIBRARY_DIRS)s

HDF5_VERSION="%(HDF5_VERSION)s"
HDF5_PATH_INCLUDES=%(HDF5_PATH_INCLUDES)s
HDF5_PATH_LIBRARIES=%(HDF5_PATH_LIBRARIES)s
HDF5_LINK_LIBRARIES=%(HDF5_LINK_LIBRARIES)s
HDF5_EXTRA_ARGS=%(HDF5_EXTRA_ARGS)s

NUMPY_VERSION="%(NUMPY_VERSION)s"
NUMPY_VERSION_API="%(NUMPY_VERSION_API)s"
NUMPY_PATH_INCLUDES=%(NUMPY_PATH_INCLUDES)s
NUMPY_PATH_LIBRARIES=%(NUMPY_PATH_LIBRARIES)s
NUMPY_LINK_LIBRARIES=%(NUMPY_LINK_LIBRARIES)s
NUMPY_EXTRA_ARGS=%(NUMPY_EXTRA_ARGS)s

PYQT_VERSION="%(PYQT_VERSION)s"
QT_VERSION="%(QT_VERSION)s"
CYTHON_VERSION="%(CYTHON_VERSION)s"
VTK_VERSION="%(VTK_VERSION)s"

__version__=6 # @@UPDATEVERSION@@
__release__=0 # @@UPDATERELEASE@@
__revision__=0 # @@UPDATEREVISION@@
__vid__="%%s.%%s.%%s"%%(__version__,__release__,__revision__)
__doc__="pyCGNS - %%s - Python package for CGNS (CFD General Notation System)"\
        %%(__vid__)
version=__vid__

NAME="%(NAME)s"
VERSION=__vid__
DESCRIPTION=__doc__
AUTHOR="%(AUTHOR)s"
EMAIL="%(EMAIL)s"
LICENSE="%(LICENSE)s"

"""
#
__version__=6 # @@UPDATEVERSION@@
__release__=0 # @@UPDATERELEASE@@
__revision__=0 # @@UPDATEREVISION@@
__vid__="%s.%s.%s"%(__version__,__release__,__revision__)
__doc__="pyCGNS - %s - Python package for CGNS (CFD General Notation System)"\
        %(__vid__)
version=__vid__
REVISION = __revision__




# common meta data
NAME = 'pyCGNS'
VERSION = __vid__
DESCRIPTION = __doc__
AUTHOR = 'Marc Poinot'
EMAIL = "marc.poinot@safrangroup.com"
LICENSE = "LGPL 2"
URL = "https://github.com/pyCGNS/pyCGNS"

# --- last line



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'CGNS/NAV/T/Q7QueryWindow.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Q7QueryWindow(object):
    def setupUi(self, Q7QueryWindow):
        Q7QueryWindow.setObjectName("Q7QueryWindow")
        Q7QueryWindow.resize(715, 350)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Q7QueryWindow.sizePolicy().hasHeightForWidth())
        Q7QueryWindow.setSizePolicy(sizePolicy)
        Q7QueryWindow.setMinimumSize(QtCore.QSize(715, 350))
        Q7QueryWindow.setMaximumSize(QtCore.QSize(715, 350))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/cgSpy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Q7QueryWindow.setWindowIcon(icon)
        self.gridLayout = QtWidgets.QGridLayout(Q7QueryWindow)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.bBackControl = QtWidgets.QPushButton(Q7QueryWindow)
        self.bBackControl.setMinimumSize(QtCore.QSize(25, 25))
        self.bBackControl.setMaximumSize(QtCore.QSize(25, 25))
        self.bBackControl.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/top.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bBackControl.setIcon(icon1)
        self.bBackControl.setObjectName("bBackControl")
        self.horizontalLayout_2.addWidget(self.bBackControl)
        self.bInfo = QtWidgets.QPushButton(Q7QueryWindow)
        self.bInfo.setMinimumSize(QtCore.QSize(25, 25))
        self.bInfo.setMaximumSize(QtCore.QSize(25, 25))
        self.bInfo.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/images/icons/help-view.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bInfo.setIcon(icon2)
        self.bInfo.setObjectName("bInfo")
        self.horizontalLayout_2.addWidget(self.bInfo)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.bClose = QtWidgets.QPushButton(Q7QueryWindow)
        self.bClose.setObjectName("bClose")
        self.horizontalLayout_2.addWidget(self.bClose)
        self.gridLayout.addLayout(self.horizontalLayout_2, 7, 1, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_2 = QtWidgets.QLabel(Q7QueryWindow)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.cQueryGroup = QtWidgets.QComboBox(Q7QueryWindow)
        self.cQueryGroup.setEnabled(True)
        self.cQueryGroup.setObjectName("cQueryGroup")
        self.horizontalLayout.addWidget(self.cQueryGroup)
        self.label = QtWidgets.QLabel(Q7QueryWindow)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.cQueryName = QtWidgets.QComboBox(Q7QueryWindow)
        self.cQueryName.setMinimumSize(QtCore.QSize(300, 0))
        self.cQueryName.setEditable(True)
        self.cQueryName.setObjectName("cQueryName")
        self.horizontalLayout.addWidget(self.cQueryName)
        self.bAdd = QtWidgets.QPushButton(Q7QueryWindow)
        self.bAdd.setMinimumSize(QtCore.QSize(25, 25))
        self.bAdd.setMaximumSize(QtCore.QSize(25, 25))
        self.bAdd.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/images/icons/operate-add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bAdd.setIcon(icon3)
        self.bAdd.setObjectName("bAdd")
        self.horizontalLayout.addWidget(self.bAdd)
        self.bDel = QtWidgets.QPushButton(Q7QueryWindow)
        self.bDel.setMinimumSize(QtCore.QSize(25, 25))
        self.bDel.setMaximumSize(QtCore.QSize(25, 25))
        self.bDel.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/images/icons/operate-delete.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bDel.setIcon(icon4)
        self.bDel.setObjectName("bDel")
        self.horizontalLayout.addWidget(self.bDel)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.bSaveAsScript = QtWidgets.QPushButton(Q7QueryWindow)
        self.bSaveAsScript.setMinimumSize(QtCore.QSize(25, 25))
        self.bSaveAsScript.setMaximumSize(QtCore.QSize(25, 25))
        self.bSaveAsScript.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/images/icons/operate-edit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSaveAsScript.setIcon(icon5)
        self.bSaveAsScript.setObjectName("bSaveAsScript")
        self.horizontalLayout.addWidget(self.bSaveAsScript)
        self.bSave = QtWidgets.QPushButton(Q7QueryWindow)
        self.bSave.setMinimumSize(QtCore.QSize(25, 25))
        self.bSave.setMaximumSize(QtCore.QSize(25, 25))
        self.bSave.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/images/icons/operate-save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bSave.setIcon(icon6)
        self.bSave.setObjectName("bSave")
        self.horizontalLayout.addWidget(self.bSave)
        self.gridLayout.addLayout(self.horizontalLayout, 3, 1, 1, 1)
        self.tabWidget = QtWidgets.QTabWidget(Q7QueryWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setMinimumSize(QtCore.QSize(695, 265))
        self.tabWidget.setMaximumSize(QtCore.QSize(695, 265))
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.eText = Q7PythonEditor(self.tab)
        self.eText.setGeometry(QtCore.QRect(10, 40, 671, 191))
        self.eText.setObjectName("eText")
        self.horizontalLayoutWidget_2 = QtWidgets.QWidget(self.tab)
        self.horizontalLayoutWidget_2.setGeometry(QtCore.QRect(10, 10, 671, 28))
        self.horizontalLayoutWidget_2.setObjectName("horizontalLayoutWidget_2")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget_2)
        self.horizontalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.cRequireUpdate = QtWidgets.QCheckBox(self.horizontalLayoutWidget_2)
        self.cRequireUpdate.setObjectName("cRequireUpdate")
        self.horizontalLayout_4.addWidget(self.cRequireUpdate)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem2)
        self.bRevert = QtWidgets.QPushButton(self.horizontalLayoutWidget_2)
        self.bRevert.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(25)
        sizePolicy.setVerticalStretch(25)
        sizePolicy.setHeightForWidth(self.bRevert.sizePolicy().hasHeightForWidth())
        self.bRevert.setSizePolicy(sizePolicy)
        self.bRevert.setMinimumSize(QtCore.QSize(25, 25))
        self.bRevert.setMaximumSize(QtCore.QSize(25, 25))
        self.bRevert.setText("")
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/images/icons/undo-at-most.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bRevert.setIcon(icon7)
        self.bRevert.setObjectName("bRevert")
        self.horizontalLayout_4.addWidget(self.bRevert)
        self.tabWidget.addTab(self.tab, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.eQueryDoc = Q7DocEditor(self.tab_3)
        self.eQueryDoc.setGeometry(QtCore.QRect(10, 40, 671, 191))
        self.eQueryDoc.setObjectName("eQueryDoc")
        self.horizontalLayoutWidget_3 = QtWidgets.QWidget(self.tab_3)
        self.horizontalLayoutWidget_3.setGeometry(QtCore.QRect(10, 10, 671, 28))
        self.horizontalLayoutWidget_3.setObjectName("horizontalLayoutWidget_3")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget_3)
        self.horizontalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem3)
        self.bRevertDoc = QtWidgets.QPushButton(self.horizontalLayoutWidget_3)
        self.bRevertDoc.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(25)
        sizePolicy.setVerticalStretch(25)
        sizePolicy.setHeightForWidth(self.bRevertDoc.sizePolicy().hasHeightForWidth())
        self.bRevertDoc.setSizePolicy(sizePolicy)
        self.bRevertDoc.setMinimumSize(QtCore.QSize(25, 25))
        self.bRevertDoc.setMaximumSize(QtCore.QSize(25, 25))
        self.bRevertDoc.setText("")
        self.bRevertDoc.setIcon(icon7)
        self.bRevertDoc.setObjectName("bRevertDoc")
        self.horizontalLayout_5.addWidget(self.bRevertDoc)
        self.bCommitDoc = QtWidgets.QPushButton(self.horizontalLayoutWidget_3)
        self.bCommitDoc.setEnabled(True)
        self.bCommitDoc.setMinimumSize(QtCore.QSize(25, 25))
        self.bCommitDoc.setMaximumSize(QtCore.QSize(25, 25))
        self.bCommitDoc.setText("")
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/images/icons/save-log.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bCommitDoc.setIcon(icon8)
        self.bCommitDoc.setObjectName("bCommitDoc")
        self.horizontalLayout_5.addWidget(self.bCommitDoc)
        self.tabWidget.addTab(self.tab_3, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayoutWidget = QtWidgets.QWidget(self.tab_2)
        self.horizontalLayoutWidget.setGeometry(QtCore.QRect(10, 10, 671, 28))
        self.horizontalLayoutWidget.setObjectName("horizontalLayoutWidget")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.bRun = QtWidgets.QPushButton(self.horizontalLayoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(25)
        sizePolicy.setVerticalStretch(25)
        sizePolicy.setHeightForWidth(self.bRun.sizePolicy().hasHeightForWidth())
        self.bRun.setSizePolicy(sizePolicy)
        self.bRun.setMinimumSize(QtCore.QSize(25, 25))
        self.bRun.setMaximumSize(QtCore.QSize(25, 25))
        self.bRun.setText("")
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/images/icons/operate-execute.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bRun.setIcon(icon9)
        self.bRun.setObjectName("bRun")
        self.horizontalLayout_3.addWidget(self.bRun)
        self.label_3 = QtWidgets.QLabel(self.horizontalLayoutWidget)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_3.addWidget(self.label_3)
        self.eUserVariable = QtWidgets.QLineEdit(self.horizontalLayoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.eUserVariable.sizePolicy().hasHeightForWidth())
        self.eUserVariable.setSizePolicy(sizePolicy)
        self.eUserVariable.setObjectName("eUserVariable")
        self.horizontalLayout_3.addWidget(self.eUserVariable)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem4)
        self.pushButton_2 = QtWidgets.QPushButton(self.horizontalLayoutWidget)
        self.pushButton_2.setEnabled(False)
        self.pushButton_2.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButton_2.setMaximumSize(QtCore.QSize(25, 25))
        self.pushButton_2.setText("")
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/images/icons/select-save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_2.setIcon(icon10)
        self.pushButton_2.setObjectName("pushButton_2")
        self.horizontalLayout_3.addWidget(self.pushButton_2)
        self.eResult = Q7PythonEditor(self.tab_2)
        self.eResult.setGeometry(QtCore.QRect(10, 40, 671, 191))
        self.eResult.setObjectName("eResult")
        self.tabWidget.addTab(self.tab_2, "")
        self.gridLayout.addWidget(self.tabWidget, 5, 1, 1, 1)

        self.retranslateUi(Q7QueryWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Q7QueryWindow)

    def retranslateUi(self, Q7QueryWindow):
        _translate = QtCore.QCoreApplication.translate
        Q7QueryWindow.setWindowTitle(_translate("Q7QueryWindow", "Form"))
        self.bClose.setText(_translate("Q7QueryWindow", "Close"))
        self.label_2.setText(_translate("Q7QueryWindow", "Group:"))
        self.cQueryGroup.setToolTip(_translate("Q7QueryWindow", "Label to caracterize a set of queries"))
        self.label.setText(_translate("Q7QueryWindow", "Query:"))
        self.cQueryName.setToolTip(_translate("Q7QueryWindow", "Query name"))
        self.bAdd.setToolTip(_translate("Q7QueryWindow", "Add as a new query"))
        self.bDel.setToolTip(_translate("Q7QueryWindow", "Delete the query"))
        self.bSaveAsScript.setToolTip(_translate("Q7QueryWindow", "Write query as single stand-alone python script"))
        self.bSave.setToolTip(_translate("Q7QueryWindow", "Save all queries in user profile directory"))
        self.cRequireUpdate.setText(_translate("Q7QueryWindow", "Script modifies tree and requires all views to update"))
        self.bRevert.setToolTip(_translate("Q7QueryWindow", "Revert to last saved text"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("Q7QueryWindow", "Python"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("Q7QueryWindow", "Documentation"))
        self.bRun.setToolTip(_translate("Q7QueryWindow", "Run query with args"))
        self.label_3.setText(_translate("Q7QueryWindow", "Args:"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("Q7QueryWindow", "Result"))
from CGNS.NAV.weditors import Q7DocEditor, Q7PythonEditor
from . import Res_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'CGNS/NAV/T/Q7InfoWindow.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Q7InfoWindow(object):
    def setupUi(self, Q7InfoWindow):
        Q7InfoWindow.setObjectName("Q7InfoWindow")
        Q7InfoWindow.setWindowModality(QtCore.Qt.ApplicationModal)
        Q7InfoWindow.resize(715, 390)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Q7InfoWindow.sizePolicy().hasHeightForWidth())
        Q7InfoWindow.setSizePolicy(sizePolicy)
        Q7InfoWindow.setMinimumSize(QtCore.QSize(715, 390))
        Q7InfoWindow.setMaximumSize(QtCore.QSize(715, 390))
        self.gridLayout = QtWidgets.QGridLayout(Q7InfoWindow)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.bInfo = QtWidgets.QPushButton(Q7InfoWindow)
        self.bInfo.setMinimumSize(QtCore.QSize(25, 25))
        self.bInfo.setMaximumSize(QtCore.QSize(25, 25))
        self.bInfo.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/help-view.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bInfo.setIcon(icon)
        self.bInfo.setObjectName("bInfo")
        self.horizontalLayout_2.addWidget(self.bInfo)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.bClose = QtWidgets.QPushButton(Q7InfoWindow)
        self.bClose.setObjectName("bClose")
        self.horizontalLayout_2.addWidget(self.bClose)
        self.gridLayout.addLayout(self.horizontalLayout_2, 7, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.groupBox_2 = QtWidgets.QGroupBox(Q7InfoWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setMinimumSize(QtCore.QSize(200, 0))
        self.groupBox_2.setMaximumSize(QtCore.QSize(200, 16777215))
        self.groupBox_2.setObjectName("groupBox_2")
        self.groupBox_4 = QtWidgets.QGroupBox(self.groupBox_2)
        self.groupBox_4.setGeometry(QtCore.QRect(10, 110, 181, 81))
        self.groupBox_4.setObjectName("groupBox_4")
        self.cHDF5 = QtWidgets.QCheckBox(self.groupBox_4)
        self.cHDF5.setGeometry(QtCore.QRect(10, 20, 94, 21))
        self.cHDF5.setCheckable(True)
        self.cHDF5.setObjectName("cHDF5")
        self.cADF = QtWidgets.QCheckBox(self.groupBox_4)
        self.cADF.setGeometry(QtCore.QRect(80, 20, 94, 21))
        self.cADF.setCheckable(True)
        self.cADF.setObjectName("cADF")
        self.label_14 = QtWidgets.QLabel(self.groupBox_4)
        self.label_14.setGeometry(QtCore.QRect(10, 50, 91, 16))
        self.label_14.setObjectName("label_14")
        self.eVersionHDF5 = QtWidgets.QLineEdit(self.groupBox_4)
        self.eVersionHDF5.setGeometry(QtCore.QRect(100, 50, 71, 22))
        self.eVersionHDF5.setReadOnly(True)
        self.eVersionHDF5.setObjectName("eVersionHDF5")
        self.label_4 = QtWidgets.QLabel(self.groupBox_2)
        self.label_4.setGeometry(QtCore.QRect(40, 20, 58, 16))
        self.label_4.setObjectName("label_4")
        self.eVersion = QtWidgets.QLineEdit(self.groupBox_2)
        self.eVersion.setGeometry(QtCore.QRect(90, 20, 71, 22))
        self.eVersion.setReadOnly(True)
        self.eVersion.setObjectName("eVersion")
        self.groupBox_5 = QtWidgets.QGroupBox(self.groupBox_2)
        self.groupBox_5.setGeometry(QtCore.QRect(10, 40, 181, 71))
        self.groupBox_5.setObjectName("groupBox_5")
        self.cREAD = QtWidgets.QCheckBox(self.groupBox_5)
        self.cREAD.setGeometry(QtCore.QRect(10, 20, 94, 21))
        self.cREAD.setCheckable(True)
        self.cREAD.setObjectName("cREAD")
        self.cMODIFY = QtWidgets.QCheckBox(self.groupBox_5)
        self.cMODIFY.setGeometry(QtCore.QRect(10, 40, 94, 21))
        self.cMODIFY.setCheckable(True)
        self.cMODIFY.setObjectName("cMODIFY")
        self.cConverted = QtWidgets.QCheckBox(self.groupBox_2)
        self.cConverted.setGeometry(QtCore.QRect(10, 200, 161, 21))
        self.cConverted.setCheckable(True)
        self.cConverted.setObjectName("cConverted")
        self.label_12 = QtWidgets.QLabel(self.groupBox_2)
        self.label_12.setGeometry(QtCore.QRect(30, 230, 161, 31))
        self.label_12.setWordWrap(True)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_3.addWidget(self.groupBox_2)
        self.groupBox_6 = QtWidgets.QGroupBox(Q7InfoWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_6.sizePolicy().hasHeightForWidth())
        self.groupBox_6.setSizePolicy(sizePolicy)
        self.groupBox_6.setMinimumSize(QtCore.QSize(220, 0))
        self.groupBox_6.setObjectName("groupBox_6")
        self.groupBox = QtWidgets.QGroupBox(self.groupBox_6)
        self.groupBox.setGeometry(QtCore.QRect(10, 130, 201, 131))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setMinimumSize(QtCore.QSize(150, 0))
        self.groupBox.setObjectName("groupBox")
        self.cHasLinks = QtWidgets.QCheckBox(self.groupBox)
        self.cHasLinks.setGeometry(QtCore.QRect(10, 20, 86, 21))
        self.cHasLinks.setCheckable(False)
        self.cHasLinks.setObjectName("cHasLinks")
        self.cSameFS = QtWidgets.QCheckBox(self.groupBox)
        self.cSameFS.setGeometry(QtCore.QRect(10, 80, 161, 21))
        self.cSameFS.setCheckable(False)
        self.cSameFS.setObjectName("cSameFS")
        self.cBadLinks = QtWidgets.QCheckBox(self.groupBox)
        self.cBadLinks.setGeometry(QtCore.QRect(10, 100, 141, 20))
        self.cBadLinks.setCheckable(False)
        self.cBadLinks.setObjectName("cBadLinks")
        self.cModeProp = QtWidgets.QCheckBox(self.groupBox)
        self.cModeProp.setGeometry(QtCore.QRect(10, 60, 131, 21))
        self.cModeProp.setCheckable(False)
        self.cModeProp.setObjectName("cModeProp")
        self.cHasInt64 = QtWidgets.QCheckBox(self.groupBox_6)
        self.cHasInt64.setGeometry(QtCore.QRect(10, 40, 201, 21))
        self.cHasInt64.setCheckable(True)
        self.cHasInt64.setObjectName("cHasInt64")
        self.cNODATA = QtWidgets.QCheckBox(self.groupBox_6)
        self.cNODATA.setGeometry(QtCore.QRect(10, 20, 201, 21))
        self.cNODATA.setCheckable(True)
        self.cNODATA.setObjectName("cNODATA")
        self.cNoFollow = QtWidgets.QCheckBox(self.groupBox_6)
        self.cNoFollow.setGeometry(QtCore.QRect(20, 170, 191, 21))
        self.cNoFollow.setCheckable(False)
        self.cNoFollow.setObjectName("cNoFollow")
        self.label_9 = QtWidgets.QLabel(self.groupBox_6)
        self.label_9.setGeometry(QtCore.QRect(10, 70, 111, 16))
        self.label_9.setObjectName("label_9")
        self.label_10 = QtWidgets.QLabel(self.groupBox_6)
        self.label_10.setGeometry(QtCore.QRect(10, 100, 81, 16))
        self.label_10.setObjectName("label_10")
        self.eNodes = QtWidgets.QLineEdit(self.groupBox_6)
        self.eNodes.setGeometry(QtCore.QRect(120, 70, 91, 22))
        self.eNodes.setReadOnly(True)
        self.eNodes.setObjectName("eNodes")
        self.eDepth = QtWidgets.QLineEdit(self.groupBox_6)
        self.eDepth.setGeometry(QtCore.QRect(120, 100, 91, 22))
        self.eDepth.setReadOnly(True)
        self.eDepth.setObjectName("eDepth")
        self.horizontalLayout_3.addWidget(self.groupBox_6)
        self.groupBox_3 = QtWidgets.QGroupBox(Q7InfoWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setMinimumSize(QtCore.QSize(250, 0))
        self.groupBox_3.setObjectName("groupBox_3")
        self.label_3 = QtWidgets.QLabel(self.groupBox_3)
        self.label_3.setGeometry(QtCore.QRect(10, 50, 81, 16))
        self.label_3.setObjectName("label_3")
        self.eFileSize = QtWidgets.QLineEdit(self.groupBox_3)
        self.eFileSize.setGeometry(QtCore.QRect(90, 20, 161, 22))
        self.eFileSize.setReadOnly(True)
        self.eFileSize.setObjectName("eFileSize")
        self.label_2 = QtWidgets.QLabel(self.groupBox_3)
        self.label_2.setGeometry(QtCore.QRect(10, 20, 58, 16))
        self.label_2.setObjectName("label_2")
        self.eMergeSize = QtWidgets.QLineEdit(self.groupBox_3)
        self.eMergeSize.setGeometry(QtCore.QRect(90, 50, 161, 22))
        self.eMergeSize.setReadOnly(True)
        self.eMergeSize.setObjectName("eMergeSize")
        self.eLastDate = QtWidgets.QLineEdit(self.groupBox_3)
        self.eLastDate.setGeometry(QtCore.QRect(90, 90, 161, 22))
        self.eLastDate.setReadOnly(True)
        self.eLastDate.setObjectName("eLastDate")
        self.label_5 = QtWidgets.QLabel(self.groupBox_3)
        self.label_5.setGeometry(QtCore.QRect(10, 90, 81, 16))
        self.label_5.setObjectName("label_5")
        self.label_6 = QtWidgets.QLabel(self.groupBox_3)
        self.label_6.setGeometry(QtCore.QRect(10, 110, 71, 31))
        self.label_6.setWordWrap(True)
        self.label_6.setObjectName("label_6")
        self.label_7 = QtWidgets.QLabel(self.groupBox_3)
        self.label_7.setGeometry(QtCore.QRect(10, 160, 58, 16))
        self.label_7.setObjectName("label_7")
        self.label_8 = QtWidgets.QLabel(self.groupBox_3)
        self.label_8.setGeometry(QtCore.QRect(10, 220, 58, 16))
        self.label_8.setObjectName("label_8")
        self.eModifDate = QtWidgets.QLineEdit(self.groupBox_3)
        self.eModifDate.setGeometry(QtCore.QRect(90, 120, 161, 22))
        self.eModifDate.setReadOnly(True)
        self.eModifDate.setObjectName("eModifDate")
        self.eOwner = QtWidgets.QLineEdit(self.groupBox_3)
        self.eOwner.setGeometry(QtCore.QRect(90, 160, 113, 22))
        self.eOwner.setReadOnly(True)
        self.eOwner.setObjectName("eOwner")
        self.eRights = QtWidgets.QLineEdit(self.groupBox_3)
        self.eRights.setGeometry(QtCore.QRect(90, 220, 113, 22))
        self.eRights.setReadOnly(True)
        self.eRights.setObjectName("eRights")
        self.eGroup = QtWidgets.QLineEdit(self.groupBox_3)
        self.eGroup.setGeometry(QtCore.QRect(90, 190, 113, 22))
        self.eGroup.setReadOnly(True)
        self.eGroup.setObjectName("eGroup")
        self.label_11 = QtWidgets.QLabel(self.groupBox_3)
        self.label_11.setGeometry(QtCore.QRect(10, 190, 58, 16))
        self.label_11.setObjectName("label_11")
        self.bHasBeenModified = QtWidgets.QPushButton(self.groupBox_3)
        self.bHasBeenModified.setEnabled(True)
        self.bHasBeenModified.setGeometry(QtCore.QRect(4, 250, 251, 25))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/subtree-sids-failed.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.bHasBeenModified.setIcon(icon1)
        self.bHasBeenModified.setCheckable(True)
        self.bHasBeenModified.setFlat(True)
        self.bHasBeenModified.setObjectName("bHasBeenModified")
        self.horizontalLayout_3.addWidget(self.groupBox_3)
        self.gridLayout.addLayout(self.horizontalLayout_3, 4, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(Q7InfoWindow)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.eFilename = QtWidgets.QLineEdit(Q7InfoWindow)
        self.eFilename.setReadOnly(True)
        self.eFilename.setObjectName("eFilename")
        self.horizontalLayout.addWidget(self.eFilename)
        self.gridLayout.addLayout(self.horizontalLayout, 3, 0, 1, 1)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.eTmpFile = QtWidgets.QLineEdit(Q7InfoWindow)
        self.eTmpFile.setReadOnly(True)
        self.eTmpFile.setObjectName("eTmpFile")
        self.gridLayout_2.addWidget(self.eTmpFile, 0, 1, 1, 1)
        self.label_13 = QtWidgets.QLabel(Q7InfoWindow)
        self.label_13.setObjectName("label_13")
        self.gridLayout_2.addWidget(self.label_13, 0, 0, 1, 1)
        self.gridLayout.addLayout(self.gridLayout_2, 6, 0, 1, 1)

        self.retranslateUi(Q7InfoWindow)
        QtCore.QMetaObject.connectSlotsByName(Q7InfoWindow)

    def retranslateUi(self, Q7InfoWindow):
        _translate = QtCore.QCoreApplication.translate
        Q7InfoWindow.setWindowTitle(_translate("Q7InfoWindow", "Form"))
        self.bClose.setText(_translate("Q7InfoWindow", "Close"))
        self.groupBox_2.setTitle(_translate("Q7InfoWindow", "CGNS"))
        self.groupBox_4.setTitle(_translate("Q7InfoWindow", "Format"))
        self.cHDF5.setText(_translate("Q7InfoWindow", "HDF5"))
        self.cADF.setText(_translate("Q7InfoWindow", "ADF"))
        self.label_14.setText(_translate("Q7InfoWindow", "HDF5 Version"))
        self.label_4.setText(_translate("Q7InfoWindow", "Version:"))
        self.groupBox_5.setTitle(_translate("Q7InfoWindow", "Mode"))
        self.cREAD.setText(_translate("Q7InfoWindow", "READ only"))
        self.cMODIFY.setText(_translate("Q7InfoWindow", "MODIFY"))
        self.cConverted.setText(_translate("Q7InfoWindow", "Is converted from ADF"))
        self.label_12.setText(_translate("Q7InfoWindow", "The TMP file name below is the actual converted file."))
        self.groupBox_6.setTitle(_translate("Q7InfoWindow", "Contents"))
        self.groupBox.setTitle(_translate("Q7InfoWindow", "Links"))
        self.cHasLinks.setText(_translate("Q7InfoWindow", "Has links"))
        self.cSameFS.setText(_translate("Q7InfoWindow", "Same file system"))
        self.cBadLinks.setText(_translate("Q7InfoWindow", "Bad links detected"))
        self.cModeProp.setText(_translate("Q7InfoWindow", "Mode propagated"))
        self.cHasInt64.setText(_translate("Q7InfoWindow", "Has double integers (int64)"))
        self.cNODATA.setText(_translate("Q7InfoWindow", "Partial data mode"))
        self.cNoFollow.setText(_translate("Q7InfoWindow", "Links not followed"))
        self.label_9.setText(_translate("Q7InfoWindow", "Number of nodes"))
        self.label_10.setText(_translate("Q7InfoWindow", "Max depth"))
        self.groupBox_3.setTitle(_translate("Q7InfoWindow", "Stat"))
        self.label_3.setText(_translate("Q7InfoWindow", "Merge size"))
        self.label_2.setText(_translate("Q7InfoWindow", "File size"))
        self.label_5.setText(_translate("Q7InfoWindow", "Last access"))
        self.label_6.setText(_translate("Q7InfoWindow", "Last modification"))
        self.label_7.setText(_translate("Q7InfoWindow", "Owner"))
        self.label_8.setText(_translate("Q7InfoWindow", "Rights"))
        self.label_11.setText(_translate("Q7InfoWindow", "Group"))
        self.bHasBeenModified.setText(_translate("Q7InfoWindow", "WARNING: File has changed on disk"))
        self.label.setText(_translate("Q7InfoWindow", "File: "))
        self.label_13.setText(_translate("Q7InfoWindow", "TMP:"))
from . import Res_rc



#  -------------------------------------------------------------------------
#  pyCGNS - Python package for CFD General Notation System -
#  See license.txt file in the root directory of this Python module source  
#  -------------------------------------------------------------------------
#

from CGNS.MAP import test
test.run()

from CGNS.PAT import test
test.run()

from CGNS.VAL import test
test.run()

from CGNS.NAV import test
test.run()

from CGNS.DAT import test
test.run()

from CGNS.APP import test
test.run()

# --- last line

